@@ -27,9 +27,12 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Cambridge, MA 02110-1301, USA
 #include <QPushButton>
 
 // KF
+#include "kio_version.h"
 #include <KIO/CopyJob>
 #include <KIO/DeleteJob>
+#if KIO_VERSION >= QT_VERSION_CHECK(5, 100, 0)
 #include <KIO/DeleteOrTrashJob>
+#endif
 #include <KIO/Job>
 #include <KIO/JobUiDelegate>
 #include <KJobWidgets>
@@ -134,6 +137,26 @@ static void delOrTrash(KIO::JobUiDelegate::DeletionType deletionType, const QLis
 {
     Q_ASSERT(urlList.count() > 0);
 
+#if KIO_VERSION < QT_VERSION_CHECK(5, 100, 0)
+    KIO::JobUiDelegate uiDelegate;
+    uiDelegate.setWindow(parent);
+    if (!uiDelegate.askDeleteConfirmation(urlList, deletionType, KIO::JobUiDelegate::DefaultConfirmation)) {
+        return;
+    }
+    KIO::Job *job = nullptr;
+    switch (deletionType) {
+    case KIO::JobUiDelegate::Trash:
+        job = KIO::trash(urlList);
+        break;
+    case KIO::JobUiDelegate::Delete:
+        job = KIO::del(urlList);
+        break;
+    default: // e.g. EmptyTrash
+        return;
+    }
+    Q_ASSERT(job);
+    KJobWidgets::setWindow(job, parent);
+#else
     KJob *job = nullptr;
     switch (deletionType) {
     case KIO::JobUiDelegate::Trash:
@@ -147,6 +170,8 @@ static void delOrTrash(KIO::JobUiDelegate::DeletionType deletionType, const QLis
     }
     Q_ASSERT(job);
     KJobWidgets::setWindow(job, parent);
+    job->start();
+#endif
 
     for (const QUrl &url : urlList) {
         DocumentFactory::instance()->forget(url);
