@@ -78,10 +78,10 @@ public:
 };
 
 struct StartMainPagePrivate : public Ui_StartMainPage {
-    StartMainPage *q;
-    GvCore *mGvCore;
-    KFilePlacesModel *mBookmarksModel;
-    ThumbnailProvider *mRecentFilesThumbnailProvider;
+    StartMainPage *q = nullptr;
+    GvCore *mGvCore = nullptr;
+    KFilePlacesModel *mBookmarksModel = nullptr;
+    ThumbnailProvider *mRecentFilesThumbnailProvider = nullptr;
     bool mSearchUiInitialized;
 
     void setupSearchUi()
@@ -105,7 +105,7 @@ struct StartMainPagePrivate : public Ui_StartMainPage {
     void setupHistoryView(ThumbnailView *view)
     {
         view->setThumbnailViewHelper(new HistoryThumbnailViewHelper(view));
-        auto *delegate = new PreviewItemDelegate(view);
+        auto delegate = new PreviewItemDelegate(view);
         delegate->setContextBarActions(PreviewItemDelegate::NoAction);
         delegate->setTextElideMode(Qt::ElideLeft);
         view->setItemDelegate(delegate);
@@ -202,7 +202,7 @@ StartMainPage::~StartMainPage()
 bool StartMainPage::eventFilter(QObject *, QEvent *event)
 {
     if (event->type() == QEvent::MouseMove) {
-        auto *mouseEvent = static_cast<QMouseEvent *>(event);
+        auto mouseEvent = static_cast<QMouseEvent *>(event);
         if (mouseEvent->source() == Qt::MouseEventSynthesizedByQt) {
             return true;
         }
