@@ -54,13 +54,14 @@ public:
         MultipleDirsFound,
     };
 
-    DocumentDirFinder(const QUrl &rootUrl);
+    explicit DocumentDirFinder(const QUrl &rootUrl);
     ~DocumentDirFinder() override;
 
     void start();
 
 Q_SIGNALS:
     void done(const QUrl &, DocumentDirFinder::Status);
+    void protocollNotSupportedError();
 
 private Q_SLOTS:
     void slotItemsAdded(const QUrl &, const KFileItemList &);
