@@ -33,17 +33,15 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Cambridge, MA 02110-1301, USA
 
 namespace Gwenview
 {
-
-struct AnimatedDocumentLoadedImplPrivate
-{
+struct AnimatedDocumentLoadedImplPrivate {
     QByteArray mRawData;
     QBuffer mMovieBuffer;
     QMovie mMovie;
 };
 
-AnimatedDocumentLoadedImpl::AnimatedDocumentLoadedImpl(Document* document, const QByteArray& rawData)
-: AbstractDocumentImpl(document)
-, d(new AnimatedDocumentLoadedImplPrivate)
+AnimatedDocumentLoadedImpl::AnimatedDocumentLoadedImpl(Document *document, const QByteArray &rawData)
+    : AbstractDocumentImpl(document)
+    , d(new AnimatedDocumentLoadedImplPrivate)
 {
     d->mRawData = rawData;
 
@@ -61,13 +59,13 @@ AnimatedDocumentLoadedImpl::~AnimatedDocumentLoadedImpl()
 
 void AnimatedDocumentLoadedImpl::init()
 {
-    emit isAnimatedUpdated();
+    Q_EMIT isAnimatedUpdated();
     if (!document()->image().isNull()) {
         // We may reach this point without an image if the first frame got
         // downsampled by LoadingDocumentImpl (unlikely for now because the gif
         // io handler does not support the QImageIOHandler::ScaledSize option)
-        emit imageRectUpdated(document()->image().rect());
-        emit loaded();
+        Q_EMIT imageRectUpdated(document()->image().rect());
+        Q_EMIT loaded();
     }
 }
 
@@ -85,7 +83,7 @@ void AnimatedDocumentLoadedImpl::slotFrameChanged(int /*frameNumber*/)
 {
     QImage image = d->mMovie.currentImage();
     setDocumentImage(image);
-    emit imageRectUpdated(image.rect());
+    Q_EMIT imageRectUpdated(image.rect());
 }
 
 bool AnimatedDocumentLoadedImpl::isAnimated() const
@@ -98,8 +96,8 @@ void AnimatedDocumentLoadedImpl::startAnimation()
     d->mMovie.start();
     if (d->mMovie.state() == QMovie::NotRunning) {
         // This is true with qt-copy as of 2008.08.23
-        //qCDebug(GWENVIEW_LIB_LOG) << "QMovie didn't start. This can happen in some cases when starting for the second time.";
-        //qCDebug(GWENVIEW_LIB_LOG) << "Trying to start again, it usually fixes the bug.";
+        // qCDebug(GWENVIEW_LIB_LOG) << "QMovie didn't start. This can happen in some cases when starting for the second time.";
+        // qCDebug(GWENVIEW_LIB_LOG) << "Trying to start again, it usually fixes the bug.";
         d->mMovie.start();
     }
 }
