@@ -33,7 +33,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 namespace Gwenview
 {
 struct JpegDocumentLoadedImplPrivate {
-    JpegContent *mJpegContent;
+    JpegContent *mJpegContent = nullptr;
 };
 
 JpegDocumentLoadedImpl::JpegDocumentLoadedImpl(Document *doc, JpegContent *jpegContent)
@@ -54,7 +54,7 @@ bool JpegDocumentLoadedImpl::saveInternal(QIODevice *device, const QByteArray &f
 {
     if (format == "jpeg") {
         if (!d->mJpegContent->thumbnail().isNull()) {
-            QImage thumbnail = document()->image().scaled(128, 128, Qt::KeepAspectRatio);
+            const QImage thumbnail = document()->image().scaled(128, 128, Qt::KeepAspectRatio);
             d->mJpegContent->setThumbnail(thumbnail);
         }
 
