@@ -23,7 +23,6 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Cambridge, MA 02110-1301, USA
 
 // Local
 #include "alphabackgrounditem.h"
-#include "gwenview_lib_debug.h"
 
 // KF
 
@@ -32,7 +31,6 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Cambridge, MA 02110-1301, USA
 #include <QCursor>
 #include <QGraphicsSceneMouseEvent>
 #include <QGuiApplication>
-#include <QPainter>
 #include <QStandardPaths>
 namespace Gwenview
 {
@@ -88,8 +86,8 @@ struct AbstractImageViewPrivate {
         }
         const QSizeF zoomedDocSize = q->dipDocumentSize() * mZoom;
         const QSizeF viewSize = q->boundingRect().size();
-        const QPointF newPos(qBound(qreal(0.), _newPos.x(), zoomedDocSize.width() - viewSize.width()),
-                             qBound(qreal(0.), _newPos.y(), zoomedDocSize.height() - viewSize.height()));
+        const QPointF newPos(qBound(qreal(0.), _newPos.x(), std::max(0., zoomedDocSize.width() - viewSize.width())),
+                             qBound(qreal(0.), _newPos.y(), std::max(0., zoomedDocSize.height() - viewSize.height())));
         if (newPos != mScrollPos) {
             const QPointF oldPos = mScrollPos;
             mScrollPos = newPos;
