@@ -35,17 +35,17 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Cambridge, MA 02110-1301, USA
 namespace Gwenview
 {
 struct LoadingIndicatorPrivate {
-    LoadingIndicator *q;
+    LoadingIndicator *q = nullptr;
     KPixmapSequence mSequence;
     int mIndex;
-    QTimer *mTimer;
+    QTimer *const mTimer;
 
     LoadingIndicatorPrivate(LoadingIndicator *qq)
         : q(qq)
         , mIndex(0)
         , mTimer(new QTimer(qq))
+        , mSequence(KIconLoader::global()->loadPixmapSequence(QStringLiteral("process-working"), 22))
     {
-        mSequence = KIconLoader::global()->loadPixmapSequence(QStringLiteral("process-working"), 22);
         mTimer->setInterval(100);
         QObject::connect(mTimer, SIGNAL(timeout()), q, SLOT(showNextFrame()));
     }
