@@ -67,7 +67,7 @@ struct HistoryItem : public QStandardItem {
             return nullptr;
         }
 
-        auto *item = new HistoryItem(url, dateTime, file.fileName());
+        auto item = new HistoryItem(url, dateTime, file.fileName());
         item->save();
         return item;
     }
@@ -77,12 +77,12 @@ struct HistoryItem : public QStandardItem {
         KConfig config(fileName, KConfig::SimpleConfig);
         KConfigGroup group(&config, "general");
 
-        QUrl url(group.readEntry("url"));
+        const QUrl url(group.readEntry("url"));
         if (!url.isValid()) {
             qCCritical(GWENVIEW_LIB_LOG) << "Invalid url" << url;
             return nullptr;
         }
-        QDateTime dateTime = QDateTime::fromString(group.readEntry("dateTime"), Qt::ISODate);
+        const QDateTime dateTime = QDateTime::fromString(group.readEntry("dateTime"), Qt::ISODate);
         if (!dateTime.isValid()) {
             qCCritical(GWENVIEW_LIB_LOG) << "Invalid dateTime" << dateTime;
             return nullptr;
@@ -128,7 +128,7 @@ private:
 #ifdef Q_OS_UNIX
         // shorten home directory, but avoid showing a cryptic "~/"
         if (text.length() > QDir::homePath().length() + 1) {
-            text.replace(QRegularExpression('^' + QDir::homePath()), QStringLiteral("~"));
+            text.replace(QRegularExpression(QLatin1Char('^') + QDir::homePath()), QStringLiteral("~"));
         }
 #endif
         setText(text);
@@ -139,7 +139,7 @@ private:
 
         setData(mUrl, KFilePlacesModel::UrlRole);
 
-        KFileItem fileItem(mUrl);
+        const KFileItem fileItem(mUrl);
         setData(QVariant(fileItem), KDirModel::FileItemRole);
 
         const QString date = KFormat().formatRelativeDateTime(mDateTime, QLocale::LongFormat);
@@ -153,7 +153,7 @@ private:
 };
 
 struct HistoryModelPrivate {
-    HistoryModel *q;
+    HistoryModel *q = nullptr;
     QString mStorageDir;
     int mMaxCount;
 
@@ -172,7 +172,7 @@ struct HistoryModelPrivate {
                 continue;
             }
 
-            QUrl itemUrl = item->url();
+            const QUrl itemUrl = item->url();
             if (UrlUtils::urlIsFastLocalFile(itemUrl)) {
                 if (!QFile::exists(itemUrl.path())) {
                     qCDebug(GWENVIEW_LIB_LOG) << "Removing" << itemUrl.path() << "from recent folders. It does not exist anymore";
@@ -227,7 +227,7 @@ HistoryModel::~HistoryModel()
 
 void HistoryModel::addUrl(const QUrl &url, const QDateTime &_dateTime)
 {
-    QDateTime dateTime = _dateTime.isValid() ? _dateTime : QDateTime::currentDateTime();
+    const QDateTime dateTime = _dateTime.isValid() ? _dateTime : QDateTime::currentDateTime();
     HistoryItem *historyItem = d->mHistoryItemForUrl.value(url);
     if (historyItem) {
         historyItem->setDateTime(dateTime);
@@ -249,7 +249,7 @@ bool HistoryModel::removeRows(int start, int count, const QModelIndex &parent)
 {
     Q_ASSERT(!parent.isValid());
     for (int row = start + count - 1; row >= start; --row) {
-        auto *historyItem = static_cast<HistoryItem *>(item(row, 0));
+        auto historyItem = static_cast<HistoryItem *>(item(row, 0));
         Q_ASSERT(historyItem);
         d->mHistoryItemForUrl.remove(historyItem->url());
         historyItem->unlink();
