@@ -39,10 +39,10 @@ namespace Gwenview
 static const int TIMEOUT = 10000;
 
 struct HudMessageBubblePrivate {
-    QGraphicsWidget *mWidget;
-    QGraphicsLinearLayout *mLayout;
-    HudCountDown *mCountDown;
-    HudLabel *mLabel;
+    QGraphicsWidget *mWidget = nullptr;
+    QGraphicsLinearLayout *mLayout = nullptr;
+    HudCountDown *mCountDown = nullptr;
+    HudLabel *mLabel = nullptr;
 };
 
 HudMessageBubble::HudMessageBubble(QGraphicsWidget *parent)
@@ -77,7 +77,7 @@ void HudMessageBubble::setText(const QString &text)
 
 HudButton *HudMessageBubble::addButton(const KGuiItem &guiItem)
 {
-    auto *button = new HudButton;
+    auto button = new HudButton;
     button->setText(guiItem.text());
     button->setIcon(guiItem.icon());
     d->mLayout->addItem(button);
