@@ -28,7 +28,6 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 
 // KF
 #include <KFileItem>
-#include <KFormat>
 #include <KLocalizedString>
 
 // Exiv2
@@ -216,14 +215,14 @@ struct ImageMetaInfoModelPrivate {
     void setGroupEntryValue(GroupRow groupRow, const QString &key, const QString &value)
     {
         MetaInfoGroup *group = mMetaInfoGroupVector[groupRow];
-        int entryRow = group->getRowForKey(key);
+        const int entryRow = group->getRowForKey(key);
         if (entryRow == MetaInfoGroup::InvalidRow) {
             qCWarning(GWENVIEW_LIB_LOG) << "No row for key" << key;
             return;
         }
         group->setValueForKeyAt(entryRow, value);
-        QModelIndex groupIndex = q->index(groupRow, 0);
-        QModelIndex entryIndex = q->index(entryRow, 1, groupIndex);
+        const QModelIndex groupIndex = q->index(groupRow, 0);
+        const QModelIndex entryIndex = q->index(entryRow, 1, groupIndex);
         Q_EMIT q->dataChanged(entryIndex, entryIndex);
     }
 
@@ -231,9 +230,9 @@ struct ImageMetaInfoModelPrivate {
     {
         if (index.internalId() == NoGroup) {
             if (index.column() != 0) {
-                return QVariant();
+                return {};
             }
-            QString label = mMetaInfoGroupVector[index.row()]->label();
+            const QString label = mMetaInfoGroupVector[index.row()]->label();
             return QVariant(label);
         }
 
@@ -277,11 +276,11 @@ struct ImageMetaInfoModelPrivate {
                 if (it->tagName().substr(0, 2) == "0x") {
                     continue;
                 }
-                QString key = QString::fromUtf8(it->key().c_str());
-                QString label = QString::fromLocal8Bit(it->tagLabel().c_str());
+                const QString key = QString::fromUtf8(it->key().c_str());
+                const QString label = QString::fromLocal8Bit(it->tagLabel().c_str());
                 std::ostringstream stream;
                 stream << *it;
-                QString value = QString::fromLocal8Bit(stream.str().c_str());
+                const QString value = QString::fromLocal8Bit(stream.str().c_str());
 
                 EntryHash::iterator hashIt = hash.find(key);
                 if (hashIt != hash.end()) {
@@ -337,7 +336,7 @@ ImageMetaInfoModel::~ImageMetaInfoModel()
 void ImageMetaInfoModel::setUrl(const QUrl &url)
 {
     KFileItem item(url);
-    const QString sizeString = KFormat().formatByteSize(item.size());
+    const QString sizeString = KIO::convertSize(item.size());
     const QString timeString = QLocale().toString(item.time(KFileItem::ModificationTime), QLocale::LongFormat);
 
     d->setGroupEntryValue(GeneralGroup, QStringLiteral("General.Name"), item.name());
@@ -485,7 +484,7 @@ QString ImageMetaInfoModel::getValueForKey(const QString &key) const
 QString ImageMetaInfoModel::keyForIndex(const QModelIndex &index) const
 {
     if (index.internalId() == NoGroup) {
-        return QString();
+        return {};
     }
     MetaInfoGroup *group = d->mMetaInfoGroupVector[index.internalId()];
     return group->getKeyAt(index.row());
@@ -494,19 +493,19 @@ QString ImageMetaInfoModel::keyForIndex(const QModelIndex &index) const
 QModelIndex ImageMetaInfoModel::index(int row, int col, const QModelIndex &parent) const
 {
     if (col < 0 || col > 1) {
-        return QModelIndex();
+        return {};
     }
     if (!parent.isValid()) {
         // This is a group
         if (row < 0 || row >= d->mMetaInfoGroupVector.size()) {
-            return QModelIndex();
+            return {};
         }
         return createIndex(row, col, col == 0 ? NoGroup : NoGroupSpace);
     } else {
         // This is an entry
         int group = parent.row();
         if (row < 0 || row >= d->mMetaInfoGroupVector[group]->size()) {
-            return QModelIndex();
+            return {};
         }
         return createIndex(row, col, group);
     }
@@ -515,10 +514,10 @@ QModelIndex ImageMetaInfoModel::index(int row, int col, const QModelIndex &paren
 QModelIndex ImageMetaInfoModel::parent(const QModelIndex &index) const
 {
     if (!index.isValid()) {
-        return QModelIndex();
+        return {};
     }
     if (index.internalId() == NoGroup || index.internalId() == NoGroupSpace) {
-        return QModelIndex();
+        return {};
     } else {
         return createIndex(index.internalId(), 0, NoGroup);
     }
@@ -543,21 +542,21 @@ int ImageMetaInfoModel::columnCount(const QModelIndex & /*parent*/) const
 QVariant ImageMetaInfoModel::data(const QModelIndex &index, int role) const
 {
     if (!index.isValid()) {
-        return QVariant();
+        return {};
     }
 
     switch (role) {
     case Qt::DisplayRole:
         return d->displayData(index);
     default:
-        return QVariant();
+        return {};
     }
 }
 
 QVariant ImageMetaInfoModel::headerData(int section, Qt::Orientation orientation, int role) const
 {
     if (orientation == Qt::Vertical || role != Qt::DisplayRole) {
-        return QVariant();
+        return {};
     }
 
     QString caption;
