@@ -29,7 +29,6 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 #include <KDirModel>
 #endif
 // Local
-#include "gwenview_lib_debug.h"
 #include <lib/archiveutils.h>
 #include <lib/timeutils.h>
 #ifndef GWENVIEW_SEMANTICINFO_BACKEND_NONE
@@ -79,9 +78,7 @@ SortedDirModel::SortedDirModel(QObject *parent)
 #endif
     setSourceModel(d->mSourceModel);
 
-#ifdef KIO_REQUEST_MIMETYPE
     d->mSourceModel->dirLister()->setRequestMimeTypeWhileListing(true);
-#endif
 
     d->mDelayedApplyFiltersTimer.setInterval(0);
     d->mDelayedApplyFiltersTimer.setSingleShot(true);
@@ -151,7 +148,7 @@ void SortedDirModel::setBlackListedExtensions(const QStringList &list)
 KFileItem SortedDirModel::itemForIndex(const QModelIndex &index) const
 {
     if (!index.isValid()) {
-        return KFileItem();
+        return {};
     }
 
     QModelIndex sourceIndex = mapToSource(index);
@@ -167,7 +164,7 @@ QUrl SortedDirModel::urlForIndex(const QModelIndex &index) const
 KFileItem SortedDirModel::itemForSourceIndex(const QModelIndex &sourceIndex) const
 {
     if (!sourceIndex.isValid()) {
-        return KFileItem();
+        return {};
     }
     return d->mSourceModel->itemForIndex(sourceIndex);
 }
@@ -175,7 +172,7 @@ KFileItem SortedDirModel::itemForSourceIndex(const QModelIndex &sourceIndex) con
 QModelIndex SortedDirModel::indexForItem(const KFileItem &item) const
 {
     if (item.isNull()) {
-        return QModelIndex();
+        return {};
     }
 
     QModelIndex sourceIndex = d->mSourceModel->indexForItem(item);
@@ -185,7 +182,7 @@ QModelIndex SortedDirModel::indexForItem(const KFileItem &item) const
 QModelIndex SortedDirModel::indexForUrl(const QUrl &url) const
 {
     if (!url.isValid()) {
-        return QModelIndex();
+        return {};
     }
     QModelIndex sourceIndex = d->mSourceModel->indexForUrl(url);
     return mapFromSource(sourceIndex);
