@@ -35,7 +35,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Cambridge, MA 02110-1301, USA
 namespace Gwenview
 {
 struct ShadowFilterPrivate {
-    QWidget *mWidget;
+    QWidget *mWidget = nullptr;
     QHash<ShadowFilter::WidgetEdge, QColor> mShadows;
 
     void paintShadow(QPainter *painter, const QColor &color, QPoint origin, int dx, int dy)
@@ -56,7 +56,7 @@ struct ShadowFilterPrivate {
     void paint()
     {
         QPainter painter(mWidget);
-        QRect rect = mWidget->rect();
+        const QRect rect = mWidget->rect();
         QColor color;
 
         color = mShadows.value(ShadowFilter::LeftEdge, Qt::transparent);
