@@ -22,6 +22,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 // STL
 #include <algorithm>
 #include <ctime>
+#include <random>
 
 // Qt
 #include <QAction>
@@ -52,29 +53,8 @@ enum State {
     WaitForEndOfUrl,
 };
 
-/**
- * This class generate random numbers which are not the same between two runs
- * of Gwenview. See bug #132334
- */
-class RandomNumberGenerator
-{
-public:
-    RandomNumberGenerator()
-        : mSeed(time(nullptr))
-    {
-    }
-
-    int operator()(int n)
-    {
-        return rand_r(&mSeed) % n;
-    }
-
-private:
-    unsigned int mSeed;
-};
-
 struct SlideShowPrivate {
-    QTimer *mTimer;
+    QTimer *mTimer = nullptr;
     State mState;
     QVector<QUrl> mUrls;
     QVector<QUrl> mShuffledUrls;
@@ -82,8 +62,8 @@ struct SlideShowPrivate {
     QUrl mCurrentUrl;
     QUrl mLastShuffledUrl;
 
-    QAction *mLoopAction;
-    QAction *mRandomAction;
+    QAction *mLoopAction = nullptr;
+    QAction *mRandomAction = nullptr;
 
     QUrl findNextUrl()
     {
@@ -116,15 +96,16 @@ struct SlideShowPrivate {
         if (it != mUrls.constEnd()) {
             return *it;
         } else {
-            return QUrl();
+            return {};
         }
     }
 
     void initShuffledUrls()
     {
         mShuffledUrls = mUrls;
-        RandomNumberGenerator generator;
-        std::random_shuffle(mShuffledUrls.begin(), mShuffledUrls.end(), generator);
+        std::random_device rd;
+        std::mt19937 generator(rd());
+        std::shuffle(mShuffledUrls.begin(), mShuffledUrls.end(), generator);
         // Ensure the first url is different from the previous last one, so that
         // last url does not stay visible twice longer than usual
         if (mLastShuffledUrl == mShuffledUrls.first() && mShuffledUrls.count() > 1) {
@@ -139,11 +120,11 @@ struct SlideShowPrivate {
             if (GwenviewConfig::loop()) {
                 initShuffledUrls();
             } else {
-                return QUrl();
+                return {};
             }
         }
 
-        QUrl url = mShuffledUrls.last();
+        const QUrl url = mShuffledUrls.last();
         mShuffledUrls.pop_back();
 
         return url;
@@ -279,7 +260,7 @@ void SlideShow::resumeAndGoToNextUrl()
 void SlideShow::goToNextUrl()
 {
     LOG("");
-    QUrl url = d->findNextUrl();
+    const QUrl url = d->findNextUrl();
     LOG("url:" << url);
     if (!url.isValid()) {
         pause();
