@@ -37,14 +37,11 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Cambridge, MA 02110-1301, USA
 #endif
 
 // KF
-#include <KIconLoader>
 
 // Local
 #include "gwenview_lib_debug.h"
 #include "gwenviewconfig.h"
-#include "lib/hud/hudtheme.h"
 #include "lib/paintutils.h"
-#include "lib/thumbnailview/abstractthumbnailviewhelper.h"
 
 namespace Gwenview
 {
@@ -70,9 +67,9 @@ struct ThumbnailBarItemDelegatePrivate {
     using ShadowCache = QMap<int, QPixmap>;
     mutable ShadowCache mShadowCache;
 
-    ThumbnailBarItemDelegate *q;
-    ThumbnailView *mView;
-    QToolButton *mToggleSelectionButton;
+    ThumbnailBarItemDelegate *q = nullptr;
+    ThumbnailView *mView = nullptr;
+    QToolButton *mToggleSelectionButton = nullptr;
 
     QColor mBorderColor;
     QPersistentModelIndex mIndexUnderCursor;
