@@ -8,7 +8,6 @@
 #include <QAction>
 #include <QEvent>
 #include <QLineEdit>
-#include <QMouseEvent>
 #include <QSignalBlocker>
 #include <QWheelEvent>
 
@@ -25,9 +24,7 @@ ZoomValidator::ZoomValidator(qreal minimum, qreal maximum, ZoomComboBox *q, Zoom
 {
 }
 
-ZoomValidator::~ZoomValidator() noexcept
-{
-}
+ZoomValidator::~ZoomValidator() noexcept = default;
 
 qreal ZoomValidator::minimum() const
 {
@@ -86,7 +83,7 @@ QValidator::State ZoomValidator::validate(QString &input, int &pos) const
 
 ZoomComboBoxPrivate::ZoomComboBoxPrivate(ZoomComboBox *q)
     : q_ptr(q)
-    , validator(new ZoomValidator(0, 0, q, this))
+    , validator(new ZoomValidator(0, 0, q, this, q))
 {
 }
 
@@ -103,7 +100,7 @@ ZoomComboBox::ZoomComboBox(QWidget *parent)
     setInsertPolicy(QComboBox::NoInsert);
     // QLocale::percent() will return a QString in Qt 6.
     // Qt encourages using QString(locale().percent()) in QLocale documentation.
-    int percentLength = QString(locale().percent()).length();
+    const int percentLength = QString(locale().percent()).length();
     setMinimumContentsLength(locale().toString(9999).length() + percentLength);
 
     connect(lineEdit(), &QLineEdit::textEdited, this, [this, d](const QString &text) {
@@ -135,9 +132,7 @@ ZoomComboBox::ZoomComboBox(QWidget *parent)
     connect(this, qOverload<int>(&ZoomComboBox::activated), this, &ZoomComboBox::activateAndChangeZoomTo);
 }
 
-ZoomComboBox::~ZoomComboBox() noexcept
-{
-}
+ZoomComboBox::~ZoomComboBox() noexcept = default;
 
 void ZoomComboBox::setActions(QAction *zoomToFitAction, QAction *zoomToFillAction, QAction *actualSizeAction)
 {
@@ -287,7 +282,7 @@ bool ZoomComboBox::eventFilter(QObject *watched, QEvent *event)
         }
         case QEvent::ShortcutOverride: {
             if (view()->isVisibleTo(this)) {
-                QKeyEvent *keyEvent = static_cast<QKeyEvent *>(event);
+                auto keyEvent = static_cast<QKeyEvent *>(event);
                 if (keyEvent->key() == Qt::Key_Escape) {
                     event->accept();
                 }
@@ -386,7 +381,7 @@ void ZoomComboBox::changeZoomTo(int index)
     }
 
     QVariant itemData = this->itemData(index);
-    QAction *action = itemData.value<QAction *>();
+    auto action = itemData.value<QAction *>();
     if (action) {
         if (!action->isCheckable() || !action->isChecked()) {
             action->trigger();
