@@ -83,11 +83,9 @@ void createEmptyFile(const QString &path)
 
 void waitForDeferredDeletes()
 {
-    while (QCoreApplication::hasPendingEvents()) {
-        QCoreApplication::sendPostedEvents();
-        QCoreApplication::sendPostedEvents(nullptr, QEvent::DeferredDelete);
-        QCoreApplication::processEvents();
-    }
+    QCoreApplication::sendPostedEvents();
+    QCoreApplication::sendPostedEvents(nullptr, QEvent::DeferredDelete);
+    QCoreApplication::processEvents();
 }
 
 namespace TestUtils
@@ -95,7 +93,7 @@ namespace TestUtils
 void purgeUserConfiguration()
 {
     QString confDir = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation);
-    QVERIFY(confDir.endsWith(".qttest/share")); // Better safe than sorry
+    QVERIFY(confDir.endsWith(QStringLiteral(".qttest/share"))); // Better safe than sorry
     if (QFileInfo(confDir).isDir()) {
         KIO::DeleteJob *deleteJob = KIO::del(QUrl::fromLocalFile(confDir));
         QVERIFY(deleteJob->exec());
